@@ -31,8 +31,8 @@ class FeaturePermissionBar : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit FeaturePermissionBar(QWidget *parent = Q_NULLPTR);
-    ~FeaturePermissionBar();
+    explicit FeaturePermissionBar(QWidget *parent = nullptr);
+    ~FeaturePermissionBar() override;
 
     QWebEnginePage::Feature feature() const;
 
